from clinicedc_constants import DM, HIV, HTN, NCD, OTHER

list_data = {
    "edc_facility.healthfacilitytypes": [
        (DM, "Diabetes Clinic"),
        (HIV, "HIV Clinic"),
        (HTN, "Hypertension Clinic"),
        (NCD, "NCD Clinic"),
        (OTHER, "Other (specify below)"),
    ],
}
